@@ -5,7 +5,7 @@ from .pixel import pixel
 from .ring import ring
 from .sunset import sunset
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 __all__ = ["avatar"]
 
@@ -21,10 +21,19 @@ VARIANTS = {
 }
 
 
-def avatar(name, colors=DEFAULT_COLORS, variant="beam", square=False):
+def avatar(
+    name: str,
+    *,
+    colors: [str] = DEFAULT_COLORS,
+    variant: str = "marble",
+    title: bool = False,
+    size: int = 40,
+    square: bool = False,
+) -> str:
+    """Generate an avatar SVG string with the given parameters."""
     if variant not in VARIANTS:
         raise ValueError(f"unrecognized variant: {variant}")
 
     fn = VARIANTS[variant]
     colors = [c.lstrip("#") for c in colors]
-    return fn(name, colors=colors, square=square)
+    return fn(name, colors=colors, size=size, title=title, square=square)
