@@ -1,9 +1,14 @@
+import hashlib
 import math
 import os.path
 
 from jinja2 import Environment, FileSystemLoader, select_autoescape
 
 
+def hash_code(name):
+    return int.from_bytes(hashlib.sha1(name.encode("utf-8")).digest())
+
+
 def get_digit(number, ntn):
     return math.floor((number / math.pow(10, ntn)) % 10)
 
